EasyExtend.langlets.p4d.bytelet.FlowLenBER

Package EasyExtend :: Package langlets :: Package p4d :: Module bytelet :: Class FlowLenBER |
[hide private]
[frames] | no frames]

# Class FlowLenBER

    object --+
             |
          Flow --+
                 |
           FlowLen --+
                     |
                    FlowLenBER

Instance Methods | [hide private]
_BER_encode(self, n) |
compute_value(self, n) |
Inherited from `FlowLen`: `__len__`, `__str__`, `update` Inherited from `FlowLen` (private): `_compute_field_len`, `_compute_rest` Inherited from `Flow`: `__add__`, `__copy__`, `__div__`, `__getitem__`, `__init__`, `__mul__`, `__radd__`, `__rdiv__`, `__rmul__`, `__rsub__`, `__sub__`, `compute`, `flow_value`, `set_flow_value`, `set_node` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### compute_value(self, n) |
Overrides: FlowLen.compute_value